@@ -1,14 +1,12 @@
 import io
-from collections import defaultdict, namedtuple, Counter
 from enum import Enum
 from typing import Type
+
+import pandas as pd
 from pydantic import BaseModel, Field
 from pymultirole_plugins.formatter import FormatterBase, FormatterParameters
-from pymultirole_plugins.schema import Document, Boundary, Annotation
+from pymultirole_plugins.schema import Document
 from starlette.responses import Response
-import lxml.etree as ET
-from Ranger import RangeBucketMap, Range
-import pandas as pd
 
 
 class OutputFormat(str, Enum):
